aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIan Lance Taylor <iant@golang.org>2010-02-01 16:26:50 -0800
committerIan Lance Taylor <iant@golang.org>2010-02-01 16:26:50 -0800
commit9a65381b77bb7d8e58e8b4a258ec54119b36a720 (patch)
treede9a2cd7decfea617a2273624921da779adbaa32
parent001d9917f46ed752c97daba24866093a75c4db7f (diff)
downloadgo-9a65381b77bb7d8e58e8b4a258ec54119b36a720.tar.gz
go-9a65381b77bb7d8e58e8b4a258ec54119b36a720.zip
Fix for gccgo, which uses a package prefix.
R=rsc CC=golang-dev https://golang.org/cl/198046
-rw-r--r--test/fixedbugs/bug248.dir/bug2.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/fixedbugs/bug248.dir/bug2.go b/test/fixedbugs/bug248.dir/bug2.go
index d562bf6041..4e02b5d9a7 100644
--- a/test/fixedbugs/bug248.dir/bug2.go
+++ b/test/fixedbugs/bug248.dir/bug2.go
@@ -37,11 +37,11 @@ func main() {
// check that reflect paths are correct,
// meaning that reflect data for v0, v1 didn't get confused.
- // path is full (rooted) path name. check suffix only.
- if s := reflect.Typeof(v0).PkgPath(); !strings.HasSuffix(s, "/bug0") {
+ // path is full (rooted) path name. check suffix for gc, prefix for gccgo
+ if s := reflect.Typeof(v0).PkgPath(); !strings.HasSuffix(s, "/bug0") && !strings.HasPrefix(s, "bug0") {
panicln("bad v0 path", len(s), s)
}
- if s := reflect.Typeof(v1).PkgPath(); !strings.HasSuffix(s, "/bug1") {
+ if s := reflect.Typeof(v1).PkgPath(); !strings.HasSuffix(s, "/bug1") && !strings.HasPrefix(s, "bug1") {
panicln("bad v1 path", s)
}